@@ -386,7 +386,27 @@ int write_to_disk(f_state *s, s_spec *needle, u_int64_t len, unsigned char *buf,
 
 	if (needle->comment == NULL)
 		strcpy(needle->comment, " ");
+	
+	if (i == 1) {
+      audit_msg(s,"%d:\t%08llu.%s \t %10s \t %10llu \t %s",
+         s->fileswritten,
+         block,
+         needle->suffix,
+         human_readable(len, temp),
+         t_offset,
+         needle->comment);
+         } else {
+      audit_msg(s,"%d:\t%08llu_%d.%s \t %10s \t %10llu \t %s",
+         s->fileswritten,
+         block,
+         i - 1,
+         needle->suffix, 
+         human_readable(len, temp),
+         t_offset,
+         needle->comment);
+         }
 
+/*
 	audit_msg(s,"%d:\t%10llu.%s \t %10s \t %10llu \t %s",
 			  s->fileswritten,
 			  block,
@@ -395,6 +415,7 @@ int write_to_disk(f_state *s, s_spec *needle, u_int64_t len, unsigned char *buf,
 			  t_offset,
 			  needle->comment);
 
+*/
 	s->fileswritten++;
 	needle->found++;
 	return TRUE;
