@@ -1758,13 +1758,11 @@ unsigned char *extract_jpeg(f_state *s, u_int64_t c_offset, unsigned char *found
 		printf("Headersize:=%d buflen:=%lld\n", headersize, buflen);
 #endif
 
-		if (headersize > buflen)
-			{
-			return NULL;
-			}
+		
+		if (((foundat + headersize) - buf) > buflen){ return NULL; }	
 
 		foundat += headersize;
-
+		
 		if (foundat[2] != (unsigned char)'\xff')
 			{
 			break;
