@@ -12,7 +12,6 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  *
- * Modification by Nick Mikus 1-23-07
  *
  */
 #include "main.h"
@@ -268,11 +267,18 @@ int main(int argc, char **argv)
 	/* Scan for valid files to open */
 	while (*argv != NULL)
 	{
+		if(strcmp(*argv,"-c")==0)
+		{
+			/*jump past the conf file so we don't process it.*/
+			argv+=2;
+		}
 		testFile = fopen(*argv, "rb");
 		if (testFile)
 		{
 			fclose(testFile);
 			dir = opendir(*argv);
+			//fprintf(stderr,"config file=%s test=%s\n",s->config_file,*argv);
+			
 			if(!strstr(s->config_file,*argv)!=0 && !dir)
 			{
 				//fprintf(stderr,"Testing %s against %s\n",*argv,s->config_file);
